"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var classnames_1 = __importDefault(require("classnames"));
var React = __importStar(require("react"));
var react_dom_1 = require("react-dom");
var supportDarkMode_1 = __importDefault(require("../__utils/supportDarkMode"));
var index_1 = __importDefault(require("../button/index"));

var AlertComponent = function (props) {
    var title = props.title, desc = props.desc, onClose = props.onClose, btnDirection = props.btnDirection;
    var btns = props.btns;
    var onBtnClick = function (onClick, btn) {
        if (onClick === void 0) { onClick = function () { }; }
        return function () {
            onClick();
            onClose(btn);
        };
    };
    var renderBtns = function () {
        if (!btns || btns.length === 0) {
            btns = [{ name: '确定', capsule: true }];
        }
        var onlyBtn = btns.length <= 1;
        return btns.map(function (btn, index) {
            var name = btn.name, className = btn.className, onClick = btn.onClick, type = btn.type, value = btn.value, otherProps = __rest(btn, ["name", "className", "onClick", "type", "value"]);
            var btnType = type;
            if (typeof type === 'undefined') {
                if (onlyBtn) {
                    btnType = 'primary';
                }
                else {
                    btnType = index === 0 ? 'default' : 'primary';
                }
            }
            return (React.createElement(index_1.default, __assign({}, otherProps, { className: className, type: btnType, key: index, capsule: true, onClick: onBtnClick(onClick, btn) }), name));
        });
    };
    return (React.createElement("div", { className: "x-alert__inner" },
        React.createElement("div", { className: "x-alert__body" },
            !!title && React.createElement("h1", null, title),
            React.createElement("div", { className: title ? 'desc' : 'desc no-title' }, desc)),
        React.createElement("div", { className: classnames_1.default('x-alert__btns', {
                'x-alert__btns--column': btnDirection === 'column',
            }) }, renderBtns())));
};
var Alert = function (params, callback) {
    var div = document.createElement('div');
    div.classList.add('x-alert', 'x-alert--show');
    if (typeof params !== 'string' && params.className) {
        div.classList.add(params.className);
    }
    if (supportDarkMode_1.default()) {
        div.classList.add('x-app--support-dark-mode');
    }
    document.body.appendChild(div);
    var close = function (btn) {
        div.classList.remove('x-alert--show');
        div.classList.add('x-alert--hide');
        setTimeout(function () {
            if (div && div.parentNode) {
                react_dom_1.unmountComponentAtNode(div);
                div.parentNode.removeChild(div);
            }
            if (callback && btn) {
                callback(btn.value);
            }
        }, 200);
    };
    if (typeof params === 'string') {
        react_dom_1.render(react_dom_1.createPortal(React.createElement(AlertComponent, { desc: params, onClose: close }), div), div);
    }
    else {
        react_dom_1.render(react_dom_1.createPortal(React.createElement(AlertComponent, __assign({}, params, { btns: params.btns, btnDirection: params.btnDirection, title: params.title || '', onClose: close })), div), div);
    }
    var resClose = close;
    return [resClose, void 0];
};
Alert.async = function (params) {
    return new Promise(function (resolve) {
        Alert(params, function (value) {
            resolve(value);
        });
    });
};
exports.default = Alert;
