"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function getError(option, xhr) {
    var msg = "cannot " + option.method + " " + option.action + " " + xhr.status + "'";
    var err = new Error(msg);
    err.status = xhr.status;
    err.method = option.method;
    err.url = option.action;
    return err;
}
function getBody(xhr) {
    var text = xhr.responseText || xhr.response;
    if (!text) {
        return text;
    }
    try {
        return JSON.parse(text);
    }
    catch (e) {
        return text;
    }
}
function upload(option) {
    var xhr = new XMLHttpRequest();
    if (option.onProgress && xhr.upload) {
        xhr.upload.onprogress = function (e) {
            if (e.total > 0) {
                e.precent = (e.loaded / e.total) * 100;
            }
            option.onProgress(e);
        };
    }
    var formData = new FormData();
    if (option.data) {
        Object.keys(option.data).forEach(function (key) {
            var value = option.data[key];
            if (Array.isArray(value)) {
                value.forEach(function (item) { return formData.append(key + "[]", item); });
                return;
            }
            formData.append(key, value);
        });
    }
    formData.append('file', option.file);
    xhr.onerror = function (e) {
        option.onError(e);
    };
    xhr.onload = function () {
        if (xhr.status < 200 || xhr.status >= 300) {
            return option.onError(getError(option, xhr), getBody(xhr));
        }
        return option.onSuccess(getBody(xhr), xhr);
    };
    xhr.open(option.method, option.action, true);
    if (option.withCredentials && 'withCredentials' in xhr) {
        xhr.withCredentials = true;
    }
    var headers = option.headers || {};
    if (headers['X-Requested-With'] !== null) {
        xhr.setRequestHeader('X-Requested-With', 'XMLHttpRequest');
    }
    Object.keys(headers).forEach(function (key) {
        if (headers[key] !== null) {
            xhr.setRequestHeader(key, headers[key]);
        }
    });
    xhr.send(formData);
    return {
        abort: function () {
            xhr.abort();
        },
    };
}
exports.default = upload;
